<script setup>
import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import MultiSelect from '@/Components/Chosen.vue';
import { ref, computed } from 'vue';
import { Head, useForm, usePage } from '@inertiajs/vue3';

const flashMessage = ref('');
const carmodel = usePage().props.carmodel;
const carMakes = computed(() => usePage().props.carMakes || []);

// Transform carMakes data to the format { label: carMake.name, value: carMake.id }
const carMakeOptions = [];
carMakes.value.forEach(item => {
    carMakeOptions.push({
        label: item.name,
        value: item.id
    });
});

const form = useForm({
    id: carmodel.id,
    name: carmodel.name,
    year: carmodel.year,
    make: carmodel.make,
});

const selectedCarYear = ref(
    carmodel.year.split(',').map(Number)
);

const selectedCarMakes = ref(
    carmodel.make.split(',').map(Number)
);

// Update the form data with the selected car year
const updateSelectedCarYear = (selected) => {
  selectedCarYear.value = selected;
};

// Update the form data with the selected car makes
const updateSelectedCarMakes = (selected) => {
  selectedCarMakes.value = selected;
};

const years = generateYears(1949, new Date().getFullYear());

function generateYears(start, end) {
  const years = [];
  for (let year = start; year <= end; year++) {
    years.push(year);
  }
  return years;
}

const reversedYears = computed(() => [...years].reverse());
const carYearOptions = [];
reversedYears.value.map(item => {
    const year = item;
    carYearOptions.push({
        label: year.toString().replace(',', ''),
        value: year
    });
});

const submit = () => {
    const carmodelID = carmodel.id;
    form.year = selectedCarYear.value.join(',');
    form.make = selectedCarMakes.value.join(',');
    form.post(route('admin.product.model.update',{id: carmodelID}), {
        onSuccess: () => {
            flashMessage.value = "Car model updated successfully!";
        },
        onError: (error) => {
            console.error(error);
        }
    });
};
</script>

<template>

    <Head title="Edit Model" />

    <AdminAuthenticatedLayout>

        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Edit Model <a :href="route('admin.products.allmodels')"  class="back-btn"> Back to list </a></h2>
        </template>

        <div class="py-12 container">

            <div v-if="flashMessage" class="mx-auto font-bold text-red-600">
                <div class="form-row">
                    <div class="col-12">
                        <h4 class="alert alert-success">{{ flashMessage }}</h4>
                    </div>
                </div>
            </div>

            <input type="hidden" id="id" v-model="form.id" />

            <div class="content-box sm:rounded-lg">
                <form @submit.prevent="submit">
                    <div class="form-row px-3">

                        <div class="mt-4 col-md-4">
                            <InputLabel for="year" value="Year" />
                            <MultiSelect :options="carYearOptions" placeholder="Select Year" :selected="selectedCarYear" @update:selected="updateSelectedCarYear"></MultiSelect>
                            <InputError class="mt-2" :message="form.errors.year" />
                        </div>

                        <div class="mt-4 col-md-4">
                            <InputLabel for="name" value="Car Maker" />
                            <MultiSelect :options="carMakeOptions" placeholder="Select Make" :selected="selectedCarMakes" @update:selected="updateSelectedCarMakes"></MultiSelect>
                            <InputError class="mt-2" :message="form.errors.make" />
                        </div>

                        <div class="mt-4 col-md-4">
                            <InputLabel for="name" value="Car Model" />

                            <TextInput
                                id="name"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.name"
                                required
                                autofocus
                                autocomplete="name"
                            />

                            <InputError class="mt-2" :message="form.errors.name" />
                        </div>

                    </div>

                    <div class="flex items-center justify-start my-4 col-md-3 col-12">
                        <PrimaryButton class="btn btn-blue" :class="{ 'opacity-25': form.processing }" :disabled="form.processing">
                            Update Model
                        </PrimaryButton>
                    </div>
                </form>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
